#install packages if necessary
#load packages
library(ape)
library(here)
library(tidyverse)
library(ggpubr)
library(phyloseq)
library(qiime2R)
library(coin)
library(rcompanion)
library(microeco)
library(file2meco)
library(stringr)
library(boxplot)
library(ggsignif)
library(labdsv)
library(indicspecies)
library(ggsignif)


############### Metadata processing ##############

#change ‘#SampleID’ in the soil_metadata.tsv to ‘SampleID’ before importing into R so it doesn’t read the first as a comment but rather the column titles
#import original metadata file
soil_metadata <- read.delim("soil_metadata.tsv")

# remove all non-BC results
soil_metadata_IDFBC <- subset(soil_metadata, Ecozone=="IDFBC")

#replace all " " in column names with "."
colnames(soil_metadata_IDFBC) <- gsub(" ", ".", colnames(soil_metadata_IDFBC))

#remove NA in CN.Ratio
soil_metadata_IDFBC <- remove_missing(soil_metadata_IDFBC, na.rm = FALSE, vars = "CN.Ratio")

#filter to only include organic layer
soil_metadata_IDFBC_O <- subset(soil_metadata_IDFBC, Horizon=="O horizon")

#remove 3 unreliable samples with total C of 2.5% (removes Sample IDs: ERR122637, ERR122637, ERR122637)
soil_metadata_IDFBC_O <- filter(soil_metadata_IDFBC_O, CN.Ratio != 22.80)

#obtain quartiles for CN.Ratio
summary(soil_metadata_IDFBC_O$CN.Ratio)

# create function that adds a column with categorical values for C:N ratio.X is the data frame, Y is the threshold for "low", and Z is the threshold for "high". 
hi_low_CN.Ratio <- function(soil_metadata_IDFBC_O, y, z) {
  soil_metadata_IDFBC_O %>%
    mutate(Relative.CN.Ratio = cut(CN.Ratio,
                                   breaks = c(-Inf, (y+(1e-8)), (z-(1e-8)), Inf),
                                   labels = c("low", "mid", "high")))}

#apply function to create C:N ratio categories
soil_metadata_IDFBC_O = hi_low_CN.Ratio(soil_metadata_IDFBC_O, 29.50, 39.20)

#save as .tsv
write.table(soil_metadata_IDFBC_O, file='20220406_soil_metadata_IDFBC_O.tsv', quote=FALSE, sep='\t', row.names = FALSE)



############# Making figures for QIIME 2 generated PCoA plots #############

#import SBSBC .qza file of PCoA plot from QIIME 2
SBS_O_wunifrac_qza<-read_qza(here::here("soil_files","SBS_O_weighted_unifrac_pcoa_results.qza"))

#join diversity metrics with the metadata
SBS_O_wunifrac_qza<-SBS_O_wunifrac_qza$data$Vectors %>%
  select(SampleID, PC1, PC2) %>%
  left_join(soil_metadata)

#create figure for weighted UniFrac PCoA plot comparing SBS sites 
SBS_sites_beta <- SBS_O_wunifrac_qza %>% ggplot(aes(x=PC1, y=PC2, color=`Site`)) +
  geom_point() +
  xlab("PC1 (25.50%)") +
  ylab("PC2 (12.68%)") +
  stat_ellipse(type = "norm", lwd = 0.8) +
  theme_bw(base_size = 18) +
  theme(panel.grid = element_blank()) + guides(color = guide_legend(title = "SBSBC Site")) +
  scale_color_manual(values = c("cyan3","brown2","goldenrod2"))

#import IDFBC .qza file of PCoA plot from QIIME 2
IDF_O_wunifrac_qza<-read_qza(here::here("soil_files","IDF_O_weighted_unifrac_pcoa_results.qza"))

#join diversity metrics with the metadata
IDF_O_wunifrac_qza<-IDF_O_wunifrac_qza$data$Vectors %>%
  select(SampleID, PC1, PC2) %>%
  left_join(soil_metadata_IDFBC_O)

#create figure for weighted UniFrac PCoA plot comparing 2 IDF sites
IDF_sites_beta <- IDF_O_wunifrac_qza %>% ggplot(aes(x=PC1, y=PC2, color=`Site`)) +
  geom_point() +
  xlab("PC1 (30.79%)") +
  ylab("PC2 (14.53%)") +
  stat_ellipse(type = "norm", lwd = 0.8) +
  theme_bw(base_size = 18) +
  theme(panel.grid = element_blank()) + guides(color = guide_legend(title = "IDFBC Site")) +
  scale_color_manual(values = c("cyan3","brown2"))

#combine SBS and IDF site PCoAs into a panel figure
sites_panel_beta <- ggarrange(SBS_sites_beta, IDF_sites_beta,labels = c("A", "B"), 
                              ncol = 1, nrow = 2, font.label=list(size=25))

#display figure, then export by clicking the export button under 'plots'
sites_panel_beta



######### Correlation Analysis and boxplot for C:N ratio vs. LTSP treatment ##########

#create data frame for LTSP and C:N ratio in IDFBC
df <- data.frame(
  LTSP = c(soil_metadata_IDFBC_O[21]),
  CNratio  = c(soil_metadata_IDFBC_O[30]))

#look at stats summary
summary(df)

#Change order, so boxplot will be ordered "REF", "OM1", "OM2"
df$LTSP.Treatment = factor(df$LTSP.Treatment, 	# Reorder factor levels
                           c("REF", "OM1", "OM2"))

#create boxplot
boxplot(CN.Ratio~LTSP.Treatment, data = df,
        xlab="LTSP Treatment", ylab = 'C:N Ratio')

#one-way ANOVA compares variance within the groups vs. variance between the groups
aov(CN.Ratio~LTSP.Treatment, data = df)
summary(aov(CN.Ratio~LTSP.Treatment, data = df))


######### Correlation Analysis and boxplot for Total % C vs. LTSP treatment ##########

#create data frame for Total % C and LTSP in IDFBC
dfC <- data.frame(
  LTSP = c(soil_metadata_IDFBC_O[21]),
  Total.C  = c(soil_metadata_IDFBC_O[26]))

#look at data frame
print(dfC)

#look at stats summary
summary(dfC)

#Change order, so boxplot will be ordered "REF", "OM1", "OM2"
dfC$LTSP.Treatment = factor(dfC$LTSP.Treatment, 	# Reorder factor levels
                            c("REF", "OM1", "OM2"))

#one-way ANOVA compares variance within the groups vs. variance between the groups
aov(Total.Carbon~LTSP.Treatment, data = dfC)
summary(aov(Total.Carbon~LTSP.Treatment, data = dfC))

#perform the pairwise Holm post-hoc method to determine which pairs of LTSP #comparison are significantly different
pairwise.t.test(dfC$Total.Carbon, df$LTSP.Treatment, p.adj='holm')

#boxplot with manually added significance
Cplot <- ggplot(dfC, aes(x = LTSP.Treatment, y = Total.Carbon)) + geom_boxplot() + ylim(30,52) +
  theme_bw() + theme(panel.grid = element_blank()) + geom_boxplot(fill = "grey") +
  labs(x = "LTSP treatment", y = "Total Carbon (%)") +
  geom_signif(comparisons = list(c("REF", "OM1")), annotations="***", y_position =50) +
  geom_signif(comparisons = list(c("REF", "OM2")), annotations="***", y_position =47)

#view figure and export manually
Cplot


######### Correlation Analysis and boxplot for Total % N vs. LTSP treatment ##########

#create data frame for LTSP and total % N in IDFBC
dfN <- data.frame(
  LTSP = c(soil_metadata_IDFBC_O[21]),
  Total.N  = c(soil_metadata_IDFBC_O[27]))

#look at data frame
print(dfN)

#look at stats summary
summary(dfN)

#Change order, so boxplot will be ordered "REF", "OM1", "OM2"
dfN$LTSP.Treatment = factor(dfN$LTSP.Treatment, 	# Reorder factor levels
                            c("REF", "OM1", "OM2"))

#create boxplot
boxplot(Total.Nitrogen~LTSP.Treatment, data = dfN,
        xlab="LTSP Treatment", ylab = 'Total % N')

#one-way ANOVA compares variance within the groups vs. variance between the groups
aov(Total.Nitrogen~LTSP.Treatment, data = dfN)
summary(aov(Total.Nitrogen~LTSP.Treatment, data = dfN))



############# Create Venn diagram for relative abundance ##############

#Setting random numbers
set.seed(711)

#Create helper functions
calculate_relative_abundance <- function(x) x / sum(x)

#create Phyloseq object
(physeq<-qza_to_phyloseq(
  features=here::here("soil_files","table.qza"),
  tree=here::here("soil_files","rooted-tree.qza"),
  taxonomy=here::here("soil_files","taxonomy.qza"),
  metadata = here::here("soil_files","20220406_soil_metadata_IDFBC_O.tsv")))

#convert phylogenetic tree from multichotomous format to dichotomous format
phy_tree(physeq) <- multi2di(phy_tree(physeq))

#Create microeco object for IDF filtered data
meco_IDF <- phyloseq2meco(physeq)

#Filter by sequencing depth
#Define minimum sequencing depth
min_seq_depth <- 500

#Remove samples that don't pass the threshold
meco_IDF$otu_table <- meco_IDF$otu_table %>% select_if(meco_IDF$sample_sums() > min_seq_depth)
#Tidy the dataset
meco_IDF$tidy_dataset()

#Calculate relative abundance
meco_IDF_RA <- clone(meco_IDF)
meco_IDF_RA$cal_abund(rel = T)

#Remove low abundant features
total_counts <- meco_IDF_RA$taxa_sums()
relative_abundance <- calculate_relative_abundance(total_counts)
abundant <- relative_abundance > 0.0005
meco_IDF_RA$otu_table <- meco_IDF_RA$otu_table [abundant,]
meco_IDF_RA$tidy_dataset()

#Create a venn diagram
dataset1 <- meco_IDF_RA$merge_samples(use_group = "Relative.CN.Ratio")
t1 <- trans_venn$new(dataset1, ratio = "numratio")
t1$plot_venn()



############## Calculating indicator taxa ##############

#Function to group asv table by higher order taxonomy
group_by_taxonomy = function(asv_table, taxonomy, rank){
  asv_table = as.data.frame(asv_table)
  taxonomy = as.data.frame(taxonomy)
  taxonomy$ASV = rownames(taxonomy)
  asv_table$ASV = rownames(asv_table)
  asv_table = inner_join(taxonomy,asv_table,by="ASV")
  asv_table$taxa = apply(asv_table[,1:rank],1,paste,collapse=" ")
  asv_table = asv_table[,-(1:8)]
  asv_table = group_by(data.frame(asv_table),taxa)
  taxa_table = as.data.frame(summarise_all(asv_table,sum))
  rownames(taxa_table) = taxa_table$taxa
  return(taxa_table[,-1])
}

#Load data
(physeq2<-qza_to_phyloseq(
  features=here::here("soil_files","table.qza"),
  tree=here::here("soil_files","rooted-tree.qza"),
  taxonomy=here::here("soil_files","taxonomy.qza"),
  metadata = here::here("soil_files","20220406_soil_metadata_IDFBC_O.tsv")))

taxa_table <- physeq2@otu_table
taxonomy <- physeq2@tax_table
metadata <- physeq2@sam_data

#Create the taxa table for the rank of taxonomy required
taxa_table = group_by_taxonomy(taxa_table, taxonomy, 5)

#Calculate indicator values
indicator_multipatt = multipatt(t(taxa_table),metadata$Relative.CN.Ratio,duleg=T)


#Look at output
summary(indicator_multipatt)

#Write output to file (only writes significant indicators)
indicator_output = capture.output(summary(indicator_multipatt,indvalcomp=TRUE))
write.table(indicator_output,file="indiciator_family_values.txt",row.names=F,quote=F)



########## Graphing relative abundance of indicator taxa ##########

#export  taxa-bar-plots3.qzv level5 csv from https://view.qiime2.org/
#import level-5.csv into R
level5 <- read_csv("level-5.csv")

#select columns with taxa and index(sampleID)
level5 <- level5 %>% select(starts_with('index') | starts_with('k_'))

#add column at the end with the total count of ASVs per sample
level5$total_count = rowSums(level5[,c(-1)])

#select columns with index(sampleID), 6 indicator taxa, and total counts
level5_select <- level5 %>% select(ends_with("index") | ends_with("Koribacteraceae") | ends_with("Bradyrhizobiaceae") | ends_with("Methylobacteriaceae") | ends_with("Geodermatophilaceae") | ends_with("count"))

#rename column titles
names(level5_select) <- c("SampleID", "Koribacteraceae", "Bradyrhizobiaceae", "Methylobacteriaceae", "Geodermatophilaceae", "total_count")

#calculate relative abundance in new dataframe called abundance
abundance <- level5_select
for (i in 2:(ncol(level5_select) - 1)) {
  abundance[i] <- abundance[i] / abundance$total_count
}

#rename column titles in abundance dataframe
names(abundance) <- c("SampleID", "Koribacteraceae_RA", "Bradyrhizobiaceae_RA", "Methylobacteriaceae_RA", "Geodermatophilaceae_RA", "total_count")

#join level5_select and abundance 
level5_select = level5_select %>% full_join(abundance, by = "SampleID")

#join level5_select and soil_metadata_IDFBC_O
level5_select = soil_metadata_IDFBC_O %>% full_join(level5_select, by = "SampleID")

#remove “mid” Relative CN.Ratio and NA rows to clean dataframe
level5_select <- level5_select %>% filter(!is.na(Relative.CN.Ratio)) %>% filter(Relative.CN.Ratio != "mid") 

#change order so boxplot will be ordered “low”, “high”
level5_select$Relative.CN.Ratio = factor(level5_select$Relative.CN.Ratio, levels = c("low","high"))

#graph relative abundance of select indicator families
Koribacteraceae <- ggplot(level5_select, aes(x = Relative.CN.Ratio, y = Koribacteraceae_RA*100, fill = Relative.CN.Ratio)) +
  geom_boxplot() + 
  labs(title = "Koribacteraceae", x = "C:N Ratio", y = "Relative abundance (%)") +
  scale_fill_manual(values = c("thistle3", "peachpuff2")) +
  guides(fill = "none") + 
  theme_bw(base_size = 18) +  theme(panel.grid = element_blank())

Bradyrhizobiaceae <- ggplot(level5_select, aes(x = Relative.CN.Ratio, y = Bradyrhizobiaceae_RA*100, fill = Relative.CN.Ratio)) +
  geom_boxplot() + 
  labs(title = "Bradyrhizobiaceae", x = "C:N Ratio", y = "Relative abundance (%)") +
  scale_fill_manual(values = c("thistle3", "peachpuff2")) +
  guides(fill = "none") + 
  theme_bw(base_size = 18) +  theme(panel.grid = element_blank())

Methylobacteriaceae <- ggplot(level5_select, aes(x = Relative.CN.Ratio, y = Methylobacteriaceae_RA*100, fill = Relative.CN.Ratio)) +
  geom_boxplot() + 
  labs(title = "Methylobacteriaceae", x = "C:N Ratio", y = "Relative abundance (%)") +
  scale_fill_manual(values = c("thistle3", "peachpuff2")) +
  guides(fill = "none") + 
  theme_bw(base_size = 18) +  theme(panel.grid = element_blank())

Geodermatophilaceae <- ggplot(level5_select, aes(x = Relative.CN.Ratio, y = Geodermatophilaceae_RA*100, fill = Relative.CN.Ratio)) +
  geom_boxplot() + 
  labs(title = "Geodermatophilaceae", x = "C:N Ratio", y = "Relative abundance (%)") +
  scale_fill_manual(values = c("thistle3", "peachpuff2")) +
  guides(fill = "none") + 
  theme_bw(base_size = 18) +  theme(panel.grid = element_blank())

#making figure panel for indicator taxa RA
indicator_RA <- ggarrange(Koribacteraceae, Bradyrhizobiaceae, Methylobacteriaceae, Geodermatophilaceae, 
                          ncol = 2, nrow = 2)

#display figure, then export by clicking the export button under 'plots'
indicator_RA
