# !/bin/bash

#Import, trimming, taxonomy assignment, IDFBC and SBSBC filtering
# Import data using a manifest and demux 
qiime tools import \
--type 'SampleData[SequencesWithQuality]' \
--m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \
--input-format SingleEndFastqManifestPhred33V2 \
--output-path demux.qza

# Create visualization of demultiplexed samples
qiime demux summarize \
--i-data demux.qza \
--o-visualization demux.qzv

# View file using qiime2 view website and decide to trim at 400 bp

# Denoising
# Determine ASVs with DADA2
qiime dada2 denoise-single \
--i-demultiplexed-seqs demux.qza \
--p-trim-left 0 \
--p-trunc-len 400 \
--o-representative-sequences rep-seqs.qza \
--o-table table.qza \
--o-denoising-stats stats.qza

# Create visualization of DADA2 stats
qiime metadata tabulate \
--m-input-file stats.qza \
--o-visualization stats.qzv

# Visualize ASVs stats
qiime feature-table summarize \
--i-table table.qza \
--o-visualization table.qzv \
--m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \

qiime feature-table tabulate-seqs \
--i-data rep-seqs.qza \
--o-visualization rep-seqs.qzv

# Assign taxonomy using gg database
qiime feature-classifier classify-sklearn \
--i-classifier /mnt/datasets/classifiers/gg-13-8-99-nb-classifier.qza \
--i-reads rep-seqs.qza \
--o-classification taxonomy3.qza

qiime metadata tabulate \
--m-input-file taxonomy.qza \
--o-visualization taxonomy.qzv

# Taxonomy barplots
qiime taxa barplot \
--i-table table.qza \
--i-taxonomy taxonomy.qza \
--m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv  \
--o-visualization taxa-bar-plots.qzv

# Excluding endosymbiont data
qiime taxa filter-table \
--i-table table.qza \
--i-taxonomy taxonomy.qza \
--p-exclude mitochondria,chloroplast \
--o-filtered-table table-no-mitochondria-no-chloroplast.qza

# Filter by metadata 
qiime feature-table filter-samples \
  --i-table table-no-mitochondria-no-chloroplast.qza \
  --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \
  --p-where "[ecozone] = 'IDFBC'" \
  --o-filtered-table IDFBC-filtered-table.qza

qiime feature-table filter-samples \
  --i-table table-no-mitochondria-no-chloroplast.qza \
  --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \
  --p-where "[ecozone] = 'SBSBC'" \
  --o-filtered-table SBSBC-filtered-table.qza

# Visualize ASVs stats
qiime feature-table summarize \
--i-table IDFBC-filtered-table.qza \
--o-visualization IDFBC-filtered-table.qzv \
 --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \

qiime feature-table summarize \
--i-table SBSBC-filtered-table.qza \
--o-visualization SBSBC-filtered-table.qzv \
 --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv 

# Generate a tree for phylogenetic diversity analyses
qiime phylogeny align-to-tree-mafft-fasttree \
  --i-sequences rep-seqs.qza \
  --o-alignment aligned-rep-seqs.qza \
  --o-masked-alignment masked-aligned-rep-seqs.qza \
  --o-tree unrooted-tree.qza \
  --o-rooted-tree rooted-tree.qza

# Generating Alpha-rarefaction curves to guide rarefaction decisions
qiime diversity alpha-rarefaction \
  --i-table IDFBC-filtered-table.qza \
  --i-phylogeny rooted-tree.qza \
  --p-max-depth 4000 \
  --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \
  --o-visualization IDFBC-alpha-rarefaction.qzv

qiime diversity alpha-rarefaction \
  --i-table SBSBC-filtered-table.qza \
  --i-phylogeny rooted-tree.qza \
  --p-max-depth 4000 \
  --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \
  --o-visualization SBSBC-alpha-rarefaction.qzv

######Preliminary look at dataset before starting project#####
# Calculate alpha- and beta-diversity metrics for IDF
qiime diversity core-metrics-phylogenetic \
  --i-phylogeny rooted-tree.qza \
  --i-table IDFBC-filtered-table.qza \
  --p-sampling-depth 2904 \
  --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \
  --output-dir IDFBC-core-metrics-results

# Calculate alpha-group-significance for IDF
qiime diversity alpha-group-significance \
  --i-alpha-diversity IDFBC-core-metrics-results/faith_pd_vector.qza \
  --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \
  --o-visualization IDFBC-core-metrics-results/faith-pd-group-significance.qzv

qiime diversity alpha-group-significance \
  --i-alpha-diversity IDFBC-core-metrics-results/evenness_vector.qza \
  --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \
  --o-visualization IDFBC-core-metrics-results/evenness-group-significance.qzv
  
# Calculate alpha- and beta-diversity metrics for SBS
qiime diversity core-metrics-phylogenetic \
  --i-phylogeny rooted-tree.qza \
  --i-table SBSBC-filtered-table.qza \
  --p-sampling-depth 1086 \
  --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \
  --output-dir SBSBC-core-metrics-results

# Calculate alpha-group-significance for SBS
qiime diversity alpha-group-significance \
  --i-alpha-diversity SBSBC-core-metrics-results/faith_pd_vector.qza \
  --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \
  --o-visualization SBSBC-core-metrics-results/faith-pd-group-significance.qzv

qiime diversity alpha-group-significance \
  --i-alpha-diversity SBSBC-core-metrics-results/evenness_vector.qza \
  --m-metadata-file /mnt/datasets/project_2/soil/MICB_421_Soil_Metadata.tsv \
  --o-visualization SBSBC-core-metrics-results/evenness-group-significance.qzv

####Begin calculating diversity metrics for manuscript######

# Filtering SBSBC O horizon
qiime feature-table filter-samples \
  --i-table SBSBC-filtered-table.qza \
  --m-metadata-file /data/soil3/soil_metadata_final.tsv \
  --p-where "[Horizon] = 'O horizon'" \
  --o-filtered-table SBSBC_O_layer-filtered-table.qza

#Diversity metrics for SBSBC O horizon
qiime diversity core-metrics-phylogenetic \
  --i-phylogeny rooted-tree.qza \
  --i-table SBSBC_O_layer-filtered-table.qza \
  --p-sampling-depth 1086 \
  --m-metadata-file /data/soil3/soil_metadata_final.tsv \
  --output-dir SBSBC_O-core-metrics-results

# PERMANOVA for SBSBC_O Site Weighted Unifrac
qiime diversity beta-group-significance \
  --i-distance-matrix weighted_unifrac_distance_matrix.qza \
  --m-metadata-file /data/soil3/soil_metadata_final.tsv \
  --m-metadata-column Site \
  --p-permutations 999 \
  --p-pairwise \
  --p-method permanova \
  --o-visualization SBSBC_O_Site-WeightedUni_permanova.qzv

# Filtering IDFBC > O horizon
qiime feature-table filter-samples \
  --i-table IDFBC-filtered-table.qza \
  --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --p-where "[Horizon] = 'O horizon'" \
  --o-filtered-table IDFBC_O_layer-filtered-table.qza

#Diversity metrics for IDFBC>O horizon
qiime diversity core-metrics-phylogenetic \
  --i-phylogeny rooted-tree.qza \
  --i-table IDFBC_O_layer-filtered-table.qza \
  --p-sampling-depth 2904 \
   --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --output-dir IDFBC_O-core-metrics-results

# Calculate alpha-group-significance for IDFBC>O horizon
qiime diversity alpha-group-significance \
  --i-alpha-diversity IDFBC_O-core-metrics-results/faith_pd_vector.qza \
   --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --o-visualization IDFBC_O-core-metrics-results/faith-pd-group-significance.qzv

qiime diversity alpha-group-significance \
  --i-alpha-diversity IDFBC_O-core-metrics-results/evenness_vector.qza \
  --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --o-visualization IDFBC_O-core-metrics-results/evenness-group-significance.qzv

# PERMANOVA for IDFBC_O Site Weighted Unifrac
qiime diversity beta-group-significance \
  --i-distance-matrix weighted_unifrac_distance_matrix.qza \
   --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --m-metadata-column Site \
  --p-permutations 999 \
  --p-pairwise \
  --p-method permanova \
  --o-visualization IDFBC_O_Site-WeightedUni_permanova.qzv

# PERMANOVA for IDFBC_O LTSP.Treatment Weighted Unifrac
qiime diversity beta-group-significance \
  --i-distance-matrix weighted_unifrac_distance_matrix.qza \
   --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --m-metadata-column LTSP.Treatment \
  --p-permutations 999 \
  --p-pairwise \
  --p-method permanova \
  --o-visualization IDFBC_O_LTSP-WeightedUni_permanova.qzv

# PERMANOVA for IDFBC_O LTSP.Treatment Unweighted Unifrac
qiime diversity beta-group-significance \
  --i-distance-matrix unweighted_unifrac_distance_matrix.qza \
   --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --m-metadata-column LTSP.Treatment \
  --p-permutations 999 \
  --p-pairwise \
  --p-method permanova \
  --o-visualization IDFBC_O_LTSP-UnweightedUni_permanova.qzv

# PERMANOVA for IDFBC_O LTSP.Treatment Bray-Curtis
qiime diversity beta-group-significance \
  --i-distance-matrix bray_curtis_distance_matrix.qza \
   --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --m-metadata-column LTSP.Treatment \
  --p-permutations 999 \
  --p-pairwise \
  --p-method permanova \
  --o-visualization IDFBC_O_LTSP-BrayCurtis_permanova.qzv

# PERMANOVA for IDFBC_O LTSP.Treatment Jaccard
qiime diversity beta-group-significance \
  --i-distance-matrix jaccard_distance_matrix.qza \
   --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --m-metadata-column LTSP.Treatment \
  --p-permutations 999 \
  --p-pairwise \
  --p-method permanova \
  --o-visualization IDFBC_O_LTSP-Jaccard_permanova.qzv

# PERMANOVA for IDFBC_O Relative.CNratio Weighted Unifrac
qiime diversity beta-group-significance \
  --i-distance-matrix weighted_unifrac_distance_matrix.qza \
   --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --m-metadata-column Relative.CN.Ratio \
  --p-permutations 999 \
  --p-pairwise \
  --p-method permanova \
  --o-visualization IDFBC_O_CN-WeightedUni_permanova.qzv

# PERMANOVA for IDFBC_O Relative.CNratio Unweighted Unifrac
qiime diversity beta-group-significance \
  --i-distance-matrix unweighted_unifrac_distance_matrix.qza \
   --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --m-metadata-column Relative.CN.Ratio \
  --p-permutations 999 \
  --p-pairwise \
  --p-method permanova \
  --o-visualization IDFBC_O_CN-UnweightedUni_permanova.qzv

# PERMANOVA for IDFBC_O Relative.CNratio Jaccard
qiime diversity beta-group-significance \
  --i-distance-matrix jaccard_distance_matrix.qza \
   --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --m-metadata-column Relative.CN.Ratio \
  --p-permutations 999 \
  --p-pairwise \
  --p-method permanova \
  --o-visualization IDFBC_O_CN-jaccard_permanova.qzv

# PERMANOVA for IDFBC_O Relative.CNratio Bray-Curtis
qiime diversity beta-group-significance \
  --i-distance-matrix bray_curtis_distance_matrix.qza \
   --m-metadata-file /data/soil3/20220406_soil_metadata_IDFBC_O.tsv \
  --m-metadata-column Relative.CN.Ratio \
  --p-permutations 999 \
  --p-pairwise \
  --p-method permanova \
  --o-visualization IDFBC_O_CN-bray_curtis_permanova.qzv

